import React, { Component } from 'react';
import PropTypes from 'prop-types';
import ArrowLeft from 'react-icons/lib/fa/angle-double-left';
import ArrowRight from 'react-icons/lib/fa/angle-double-right';
import TableHeader from './tableHeader';
import TableBody from './tableBody';
import Search from './search';
import { getNoOfPages, isEmpty } from '../../utils/CommonUtils';

class Table extends Component {
  constructor(props) {
    super(props);
    this.onPageDecrement = this.onPageDecrement.bind(this);
    this.onPageIncrement = this.onPageIncrement.bind(this);
    this.onSearch = this.onSearch.bind(this);
    this.onSort = this.onSort.bind(this);
    this.renderPagination = this.renderPagination.bind(this);
    this.renderArrowLeft = this.renderArrowLeft.bind(this);
    this.renderArrowRight = this.renderArrowRight.bind(this);
  }

  onSort(colId) {
    this.props.onSort(colId);
  }

  onSearch(searchInput) {
    this.props.onSearch(searchInput);
  }

  dataLength() {
    if (!isEmpty(this.props.gridState.data)) {
      return this.props.gridState.data.length;
    }
    return 0;
  }

  onPageDecrement() {
    this.props.onPagination('decr');
  }

  onPageIncrement() {
    this.props.onPagination('incr');
  }

  render() {
    return (
      <div className="table">
        <table style={this.props.styleData.gridTable}>
          <thead style={this.props.styleData.gridTableThead}>
            <tr className="total-record-row" style={this.props.styleData.gridTableTR}>
              <th colSpan="4" style={this.props.styleData.gridTableTH}>
                <span>{this.renderPagination()}</span>
                <Search
                  metaData={this.props.metaData.headerConfig}
                  onSearch={this.onSearch}
                />
              </th>
            </tr>
            <tr className="table-header" style={this.props.styleData.gridTableTR}>
              <TableHeader
                metaData={this.props.metaData.headerConfig}
                styleData={this.props.styleData}
                onSort={this.onSort}
              />
            </tr>
          </thead>
          <tbody style={this.props.styleData.gridTableTbody}>
            <TableBody
              tableData={this.props.data}
              metaData={this.props.metaData}
              styleData={this.props.styleData}
            />
          </tbody>
          <tfoot>
            <th colSpan="4" className="table-footer-wrapper">
              <td className="table-footer-data">
                  Total Records: {this.dataLength()}
              </td>
            </th>
          </tfoot>
        </table>
      </div>
    );
  }

  renderPagination() {
    return (
      <div className="pagination-wrapper">
        {this.renderArrowLeft()}
        <span className="pagination-info">Page: {this.props.gridState.currentPage}/{getNoOfPages(this.props.gridState.data, this.props.gridState.recordsPerPage)} </span>
        {this.renderArrowRight()}
      </div>
    );
  }

  renderArrowLeft() {
    if (this.props.gridState.currentPage > 1) {
      return (
        <span onClick={this.onPageDecrement}>
          <ArrowLeft /><ArrowLeft />
        </span>
      );
    }
  }

  renderArrowRight() {
    if (this.props.gridState.currentPage < getNoOfPages(this.props.gridState.data, this.props.gridState.recordsPerPage)) {
      return (
        <span onClick={this.onPageIncrement}>
          <ArrowRight /><ArrowRight />
        </span>
      );
    }
  }

}

Table.propTypes = {
  data: PropTypes.array,
  metaData: PropTypes.object,
  styleData: PropTypes.object,
};

Table.defaultProps = {
  data: [],
  metaData: {},
  styleData: {},
};

export default Table;
