import React from 'react';
import PropTypes from 'prop-types';

const TableBody = ({ tableData, metaData, styleData }) => {
  if (!tableData) {
    return null;
  }
  return tableData.map(rowData => <Row data={rowData} metaData={metaData} styleData={styleData} key={rowData.id} />);
};

const Row = ({ data, metaData, styleData }) => (
  <tr style={styleData.gridTableTR}>
    {metaData.headerConfig.map(colMetaData => (
      <RowColumn
        value={data[colMetaData.key]}
        styleData={styleData}
        key={colMetaData.key}
      />
    ))}
  </tr>
);

const RowColumn = ({ value, styleData }) => (
  <td style={styleData.gridTableTD}>{value}</td>
);

TableBody.propTypes = {
  data: PropTypes.array,
  metaData: PropTypes.object,
  styleData: PropTypes.object,
};

TableBody.defaultProps = {
  data: [],
  metaData: {},
  styleData: {},
};

export default TableBody;
