/* eslint-disable react/jsx-filename-extension */
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import lodash from 'lodash';
import { getFilterData, getNoOfPages, getData, addUniqueKey } from './utils/CommonUtils';
import './datagrid.css';
import DataGridSection from './components/dataGrid/DataGrid';

class DataGrid extends Component {
  constructor(props) {
    super(props);
    this.onSearch = this.onSearch.bind(this);
    this.onSort = this.onSort.bind(this);
    this.onPagination = this.onPagination.bind(this);
    this.state = {
      data: addUniqueKey(this.props.data),
      metaData: this.props.metaData,
      styleData: this.props.styleData,
      sortOrder: 'asc',
      currentPage: 1,
      recordsPerPage: this.props.metaData.recordsPerPage,
      indexOfLastRecord: this.props.metaData.recordsPerPage,
      indexOfFirstRecord: 0,
      noOfPages: getNoOfPages(this.props.data, this.props.metaData.recordsPerPage),
    };
  }

  onSearch(searchInput) {
    const filterConfig = {
      searchEntity: searchInput.searchEntity,
      selectedColumn: searchInput.selectedColumn,
    };
    const searchData = getFilterData(filterConfig, this.props.data);
    this.setState({
      data: searchData,
      currentPage: 1,
    });
  }

  onSort(colId) {
    if (this.state.sortOrder === 'asc') {
      const sortedData = lodash.orderBy(this.state.data, [colId], ['asc']);
      this.setState({
        data: sortedData,
        sortOrder: 'desc',
      });
    } else {
      const sortedData = lodash.orderBy(this.state.data, [colId], ['desc']);
      this.setState({
        data: sortedData,
        sortOrder: 'asc',
      });
    }
  }

  onPagination(val) {
    const noOfPages = getNoOfPages(this.state.data, this.state.recordsPerPage);
    if (val === 'incr' && this.state.currentPage < noOfPages) {
      this.setState({
        currentPage: this.state.currentPage + 1,
      });
    }
    if (val === 'decr' && this.state.currentPage > 1) {
      this.setState({
        currentPage: this.state.currentPage - 1,
      });
    }
  }

  render() {
    return (
      <DataGridSection
        data={getData(this.state)}
        metaData={this.state.metaData}
        styleData={this.props.styleData}
        onSort={this.onSort}
        onSearch={this.onSearch}
        onPagination={this.onPagination}
        gridState={this.state}
      />
    );
  }
}

DataGrid.propTypes = {
  data: PropTypes.array,
  metaData: PropTypes.object,
  styleData: PropTypes.object,
};

DataGrid.defaultProps = {
  data: [],
  metaData: {},
  styleData: {},
};

export default DataGrid;
